<?php

/**
 * This source file is subject to the GNU GENERAL PUBLIC LICENSE (GPL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://www.gnu.org/licenses/gpl-3.0.txt
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit;
} // Exit if accessed directly

if( !class_exists( 'essenziale_admin_notice' ) ) {

	class essenziale_admin_notice {

		/**
		 * Constructor
		 */

		public function __construct( $fields = array() ) {

			if (
				!get_option( 'essenziale-dismissed-notice') &&
				version_compare( PHP_VERSION, ESSENZIALE_MIN_PHP_VERSION, '>=' )
			) {

				add_action( 'admin_notices', array(&$this, 'admin_notice') );
				add_action( 'admin_head', array( $this, 'dismiss' ) );

			}

		}

		/**
		 * Dismiss notice.
		 */

		public function dismiss() {

			if ( isset( $_GET['essenziale-dismiss'] ) && check_admin_referer( 'essenziale-dismiss-action' ) ) {

				update_option( 'essenziale-dismissed-notice', intval($_GET['essenziale-dismiss']) );
				remove_action( 'admin_notices', array(&$this, 'admin_notice') );

			}

		}

		/**
		 * Admin notice.
		 */

		public function admin_notice() {

		?>

            <div class="notice notice-warning is-dismissible">

            	<p>

            		<strong>

						<?php

                            esc_html_e( 'Pay what you want for the premium version of Essenziale and receive 10 additional WordPress products as a bonus. (Minimum price allowed: €5) ', 'essenziale' ); 

							printf(
								'<a href="%1$s" class="dismiss-notice">' . esc_html__( 'Dismiss this notice', 'essenziale' ) . '</a>',
								esc_url( wp_nonce_url( add_query_arg( 'essenziale-dismiss', '1' ), 'essenziale-dismiss-action'))
							);

                        ?>

                    </strong>

            	</p>

            	<p>

                    <a target="_blank" href="<?php echo esc_url( 'https://www.themeinprogress.com/essenziale/?ref=2&campaign=essenziale-notice' ); ?>" class="button button-primary"><?php esc_html_e( 'Buy now', 'essenziale' ); ?></a>

            	</p>

            </div>

		<?php

		}

	}

}

new essenziale_admin_notice();

?>
