<?php

/**
 *
 * This source file is subject to the GNU GENERAL PUBLIC LICENSE (GPL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://www.gnu.org/licenses/gpl-3.0.txt
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit;
} // Exit if accessed directly


class essenziale_upsell {

	public function __construct() {
	
		add_action ('customize_controls_enqueue_scripts' , array( &$this, 'customize_scripts' ) );
		add_action ('customize_register' , array( &$this, 'customize_panel' ) );
	
	}

	public function customize_scripts() {

		wp_enqueue_style (
			'essenziale-customize-style',
			get_template_directory_uri() . '/core/assets/css/customize.css',
			array(),
			''
		);

	}

	public function customize_panel ($wp_customize) {

		/* Upsell
		   ========================================================================== */
		
		$wp_customize->add_section( 'essenziale-customize-info', array(
			'title' => esc_html__( 'Upgrade to Essenziale Pro','essenziale'),
			'priority' => '09',
			'capability' => 'edit_theme_options',
		));

		$wp_customize->add_setting( 'essenziale-customize-info', array(
			'sanitize_callback' => 'esc_url_raw'
		));

		$wp_customize->add_control( new Essenziale_Customize_Info_Control( $wp_customize,  'essenziale-customize-info' , array(
			'section' => 'essenziale-customize-info',
		)));

	}

}

new essenziale_upsell();

if ( class_exists( 'WP_Customize_Control' ) ) {

	class Essenziale_Customize_Info_Control extends WP_Customize_Control {

		public $type = "essenziale-customize-info";

		public function render_content() { ?>

            <div class="inside">
                
                <p><?php esc_html_e('Pay what you want for the premium version of Essenziale and receive 10 additional WordPress products as a bonus. (Minimum price allowed: €5)','essenziale');?></p>

                <h2><?php esc_html_e('Pro features of Essenziale','essenziale');?></h2>

                <ul class="features-list">

                	<li><span class="dashicon dashicons dashicons-yes"></span><?php esc_html_e('Additional header layout','essenziale');?></li>
                	<li><span class="dashicon dashicons dashicons-yes"></span><?php esc_html_e('Left sidebar layout for posts and pages','essenziale');?></li>
                	<li><span class="dashicon dashicons dashicons-yes"></span><?php esc_html_e('Full width layout for posts and pages','essenziale');?></li>
                	<li><span class="dashicon dashicons dashicons-yes"></span><?php esc_html_e('Optional header image','essenziale');?></li>
                	<li><span class="dashicon dashicons dashicons-yes"></span><?php esc_html_e('600+ Google Fonts','essenziale');?></li>
                	<li><span class="dashicon dashicons dashicons-yes"></span><?php esc_html_e('Remove the articles in the carousel from the recent posts on homepage','essenziale');?></li>
                	<li><span class="dashicon dashicons dashicons-yes"></span><?php esc_html_e('Remove the copyright text from the footer','essenziale');?></li>
                	<li><span class="dashicon dashicons dashicons-yes"></span><?php esc_html_e('Social icons on footer','essenziale');?></li>
                	<li><span class="dashicon dashicons dashicons-yes"></span><?php esc_html_e('Choose custom colors','essenziale');?></li>
                	<li><span class="dashicon dashicons dashicons-yes"></span><?php esc_html_e('30 days money back guarantee','essenziale');?></li>

                </ul>

                <ul>
                
                    <li><a class="button demo-button" href="<?php echo esc_url( 'https://demo.themeinprogress.com/?theme=Essenziale' ); ?>" title="<?php esc_attr_e('View live demo','essenziale');?>" target="_blank"><?php esc_html_e('View live demo','essenziale');?></a></li>
                    <li><a class="button purchase-button" href="<?php echo esc_url( 'https://www.themeinprogress.com/essenziale/?ref=2&campaign=essenziale-panel' ); ?>" title="<?php esc_attr_e('Upgrade to Essenziale Pro','essenziale');?>" target="_blank"><?php esc_html_e('Upgrade to Essenziale Pro','essenziale');?></a></li>
                
                </ul>

            </div>

            <div class="inside">

                <h2><?php esc_html_e('Become a supporter','essenziale');?></h2>
                <p><?php esc_html_e("If you like this theme and support, I'd appreciate any of the following:","essenziale");?></p>

                <ul>

                    <li><a class="button" href="<?php echo esc_url( 'https://wordpress.org/support/view/theme-reviews/'.get_stylesheet().'#postform' ); ?>" title="<?php esc_attr_e('Rate this Theme','essenziale');?>" target="_blank"><?php esc_html_e('Rate this Theme','essenziale');?></a></li>
                    <li><a class="button" href="<?php echo esc_url( 'https://www.themeinprogress.com/reserved-area/' ); ?>" title="<?php esc_attr_e('Subscribe our newsletter','essenziale');?>" target="_blank"><?php esc_html_e('Subscribe our newsletter','essenziale');?></a></li>

                </ul>

            </div>

		<?php

		}

	}

}

?>