<?php

define( 'ESSENZIALE_MIN_PHP_VERSION', '5.3' );

/*-----------------------------------------------------------------------------------*/
/* Enqueue script and styles */
/*-----------------------------------------------------------------------------------*/

if (!function_exists('essenziale_enqueue_scripts')) {

	function essenziale_enqueue_scripts() {

		wp_enqueue_style('essenziale-style', get_stylesheet_uri(), array() );
 
 		$googleFontsArgs = array(
			'family' =>	str_replace('|', '%7C','Crimson+Text:ital,wght@0,400;0,600;0,700;1,400;1,600;1,700&family=Montserrat:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,100;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900&display=swap'),
			'subset' =>	'latin,latin-ext'
		);

		wp_enqueue_style('google-fonts', add_query_arg ( $googleFontsArgs, "https://fonts.googleapis.com/css" ), array(), '1.0.0' );

		wp_enqueue_style(
			'bootstrap-grid',
			get_template_directory_uri() . '/css/bootstrap-grid.css',
			array(),'4.5.0'
		);

		wp_enqueue_style(
			'owl.carousel',
			get_template_directory_uri() . '/css/owl.carousel.css',
			array(),'2.3.4'
		);

		wp_enqueue_style(
			'owl.theme.default',
			get_template_directory_uri() . '/css/owl.theme.default.css',
			array(),'2.3.4'
		);

		wp_enqueue_script(
			'fitvids', 
			get_template_directory_uri() . '/js/jquery.fitvids.js',
			array('jquery'),
			'1.1',
			TRUE
		);

		wp_enqueue_script(
			'essenziale-navigation',
			get_template_directory_uri() . '/js/navigation.js',
			FALSE,
			'1.0',
			TRUE
		);

		wp_enqueue_script(
			'owl.carousel',
			get_template_directory_uri() . '/js/owl.carousel.js',
			array('jquery'),
			'2.3.4',
			TRUE
		);

		wp_enqueue_script(
			'essenziale-script',
			get_template_directory_uri() . '/js/script.js',
			array('jquery', 'imagesloaded'),
			'1.0',
			TRUE
		);
		
		if ( is_singular() ) wp_enqueue_script( 'comment-reply' );

		$inlineCSS = '';

		if ( is_singular() && get_the_post_thumbnail_url() ) {
	
			$inlineCSS .= '
					
				body.has_post_thumbnail .post-thumbnail {
					background-image: url('.esc_url(get_the_post_thumbnail_url()).');
					-webkit-background-size: cover !important;
					-moz-background-size: cover !important;
					-o-background-size: cover !important;
					background-size: cover !important;
					background-position: center;
				};
					
			';
	
		}

		wp_add_inline_style( 'essenziale-style', $inlineCSS );

	}

	add_action( 'wp_enqueue_scripts', 'essenziale_enqueue_scripts', 999 );

}

/*-----------------------------------------------------------------------------------*/
/* Setup theme */
/*-----------------------------------------------------------------------------------*/

if (!function_exists('essenziale_after_setup_theme')) {

	function essenziale_after_setup_theme() {

		load_theme_textdomain('essenziale', get_template_directory() . '/languages');

		if ( !isset( $content_width ) ) $content_width = 900;

		register_nav_menus( array(
			'main-menu' => esc_html__( 'Main menu', 'essenziale' ),
		));

		add_theme_support('title-tag');
		add_theme_support('automatic-feed-links');
		add_theme_support('post-thumbnails');
		add_theme_support('custom-logo');

		add_image_size(
			'essenziale_carousel_thumbnail',
			581,
			380,
			true
		);

		require_once( trailingslashit( get_template_directory() ) . '/core/includes/class-notice.php' );
		require_once( trailingslashit( get_template_directory() ) . '/core/includes/class-plugin-activation.php' );
		require_once( trailingslashit( get_template_directory() ) . '/core/includes/class-upsell.php' );
		require_once( trailingslashit( get_template_directory() ) . '/core/includes/class-welcome-page.php' );
		require_once( trailingslashit( get_template_directory() ) . '/core/functions/function-required-plugins.php' );

	}

	add_action( 'after_setup_theme', 'essenziale_after_setup_theme', 999 );

}

/*-----------------------------------------------------------------------------------*/
/* widgets init */
/*-----------------------------------------------------------------------------------*/

if (!function_exists('essenziale_widgets_init')) {

	function essenziale_widgets_init() {

		register_sidebar(array(

			'name' => esc_html__('Sidebar','essenziale'),
			'id'   => 'essenziale-sidebar',
			'description'   => esc_html__('This sidebar will be shown next to the content.', 'essenziale'),
			'before_widget' => '<div id="%1$s" class="sidebar-widget content-area %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h2 class="title">',
			'after_title'   => '</h2>'

		));

		register_sidebar(array(

			'name' => esc_html__('Footer sidebar','essenziale'),
			'id'   => 'essenziale-footer-sidebar',
			'description'   => esc_html__('This sidebar will be shown next at the bottom of your content.', 'essenziale'),
			'before_widget' => '<div id="%1$s" class="col-md-3 content-area %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h2 class="title">',
			'after_title'   => '</h2>'

		));

	}

	add_action( 'widgets_init', 'essenziale_widgets_init' );

}

/*-----------------------------------------------------------------------------------*/
/* Body class */
/*-----------------------------------------------------------------------------------*/

if (!function_exists('essenziale_body_class')) {

	function essenziale_body_class($classes) {
	
		if (has_post_thumbnail()) {
			$classes[] = 'has_post_thumbnail';
		}
	
		return $classes;
	
	}
	
	add_filter('body_class', 'essenziale_body_class');

}

/*-----------------------------------------------------------------------------------*/
/* Post class */
/*-----------------------------------------------------------------------------------*/

if (!function_exists('essenziale_post_class')) {

	function essenziale_post_class($classes) {
		
		if (
			is_home() ||
			is_archive() ||
			is_search()
		) :

			$classes[] = 'content-area';

		endif;

		return $classes;

	}

	add_filter('post_class', 'essenziale_post_class');

}

/*-----------------------------------------------------------------------------------*/
/* Customize register */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('essenziale_customize_register')) {

	function essenziale_customize_register( $wp_customize ) {
		
		$wp_customize->add_panel('essenziale_panel', array(
			'title' => esc_html__( 'Essenziale settings', 'essenziale' ),
			'priority' => '10',
		));

		/* Carousel section
		   ========================================================================== */
		
		$wp_customize->add_section('essenziale_carousel_settings', array(
			'title' => esc_html__( 'Carousel settings', 'essenziale' ),
			'panel' => 'essenziale_panel',
		));
		
		/**
		 * Hide carousel option
		 */
		
		$wp_customize->add_setting( 'essenziale_carousel', array(
			'default' => true,
			'sanitize_callback' => 'essenziale_checkbox_sanize',
		));
	
		$wp_customize->add_control( 'essenziale_carousel', array(
			'type' => 'checkbox',
			'section' => 'essenziale_carousel_settings',
			'label' => esc_html__('Homepage carousel.', 'essenziale'),
			'description' => esc_html__('Do you want to display the carousel on homepage?.', 'essenziale'),
		));
	
		/* Content section
		   ========================================================================== */
		
		$wp_customize->add_section('essenziale_content_settings', array(
			'title' => esc_html__( 'Content settings', 'essenziale' ),
			'panel' => 'essenziale_panel',
		));
		
		/**
		 * Hide content info option
		 */
		
		$wp_customize->add_setting( 'essenziale_content_info', array(
			'default' => true,
			'sanitize_callback' => 'essenziale_checkbox_sanize',
		));
	
		$wp_customize->add_control( 'essenziale_content_info', array(
			'type' => 'checkbox',
			'section' => 'essenziale_content_settings',
			'label' => esc_html__('Content informations.', 'essenziale'),
			'description' => esc_html__('Do you want to display the informations of current content?.', 'essenziale'),
		));
	
		/* Footer section
		   ========================================================================== */
		
		$wp_customize->add_section('essenziale_footer_settings', array(
			'title' => esc_html__( 'Footer settings', 'essenziale' ),
			'panel' => 'essenziale_panel',
		));
	
		/**
		 * Footer text option
		 */
		
		$wp_customize->add_setting( 'essenziale_footer_text', array(
			'default' => '',
			'sanitize_callback' => 'sanitize_textarea_field',
		));
	
		$wp_customize->add_control( 'essenziale_footer_text', array(
			'type' => 'textarea',
			'section' => 'essenziale_footer_settings',
			'label' => esc_html__('Footer text.', 'essenziale'),
			'description' => esc_html__('Insert here the content of footer.', 'essenziale'),
		));

		/* Checkbox sanize
		   ========================================================================== */
		
		function essenziale_checkbox_sanize( $input ) {
			return $input ? true : false;
		}
	
	}
	
	add_action( 'customize_register', 'essenziale_customize_register' );

}

/*-----------------------------------------------------------------------------------*/
/* Responsive embed */
/*-----------------------------------------------------------------------------------*/

if (!function_exists('essenziale_embed_html')) {

	function essenziale_embed_html( $html ) {
		return '<div class="embed-container">' . $html . '</div>';
	}

	add_filter( 'embed_oembed_html', 'essenziale_embed_html', 10, 3 );
	add_filter( 'video_embed_html', 'essenziale_embed_html' );

}

/*-----------------------------------------------------------------------------------*/
/* Get post comments */
/*-----------------------------------------------------------------------------------*/

if ( ! function_exists( 'essenziale_list_comments' ) ) {

	function essenziale_list_comments($comment, $args, $depth) {

?>

		<li <?php comment_class(); ?> id="li-comment-<?php comment_ID() ?>">

			<div id="comment-<?php comment_ID(); ?>" class="comment-container">

				<div class="comment-avatar">
					<?php echo get_avatar($comment->comment_author_email, 80, 'retro' ); ?>
				</div>

				<div class="comment-text">

					<header class="comment-author">

						<span class="author"><cite><?php printf( esc_html__('%s has written:','essenziale'), get_comment_author_link());?> </cite></span>

						<time datetime="<?php echo esc_attr(get_comment_date())?>" class="comment-date">

							<a href="<?php echo esc_url( get_comment_link( $comment->comment_ID ) ) ?>">
								<?php printf(esc_html__('%1$s at %2$s','essenziale'), get_comment_date(),  get_comment_time()) ?>
							</a>

							<?php

								comment_reply_link(
									array_merge(
										$args,
										array(
											'depth' => $depth,
											'max_depth' => $args['max_depth']
										)
									)
								);

								edit_comment_link(esc_html__('(Edit)', 'essenziale'));

							?>

						</time>

					</header>

					<?php if ($comment->comment_approved == '0') : ?>

						<p><em><?php esc_html_e('Your comment is awaiting approval.','essenziale') ?></em></p>

					<?php endif; ?>

					<?php comment_text() ?>

				</div>

			</div>

		<?php

	}

}

?>